# Generated by Django 5.2 on 2025-07-26 17:37

import bionty.uids
import lamindb.base.fields
import lamindb.base.uids
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("wetlab", "0038_alter_biologic_branch_alter_biologic_space_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="biologic",
            name="description",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="biologic",
            name="synonyms",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="biologic",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                db_index=True,
                default=lamindb.base.uids.base62_12,
                max_length=12,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="description",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                db_index=True,
                default=lamindb.base.uids.base62_12,
                max_length=12,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="combinationperturbation",
            name="description",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="combinationperturbation",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                db_index=True,
                default=lamindb.base.uids.base62_12,
                max_length=12,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="compound",
            name="description",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="compound",
            name="synonyms",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="compound",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                db_index=True,
                default=bionty.uids.ontology,
                max_length=14,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="compoundperturbation",
            name="description",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="compoundperturbation",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                db_index=True,
                default=lamindb.base.uids.base62_12,
                max_length=12,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="donor",
            name="description",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="donor",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                db_index=True,
                default=lamindb.base.uids.base62_12,
                max_length=12,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="environmentalperturbation",
            name="description",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="environmentalperturbation",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                db_index=True,
                default=lamindb.base.uids.base62_12,
                max_length=12,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="experiment",
            name="description",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="experiment",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                db_index=True,
                default=lamindb.base.uids.base62_8,
                max_length=8,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="geneticperturbation",
            name="description",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="geneticperturbation",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                db_index=True,
                default=lamindb.base.uids.base62_12,
                max_length=12,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="perturbationtarget",
            name="description",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="perturbationtarget",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                db_index=True,
                default=lamindb.base.uids.base62_8,
                max_length=8,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="techsample",
            name="description",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="techsample",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                db_index=True,
                default=lamindb.base.uids.base62_12,
                max_length=12,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="well",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                db_index=True,
                default=lamindb.base.uids.base62_4,
                max_length=4,
                unique=True,
            ),
        ),
    ]
