# Generated by Django 5.2 on 2025-11-18 20:33

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("wetlab", "0046_artifactgeneticperturbation_wetlab_arti_artifac_8731fa_idx"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="artifactperturbationtarget",
            index=models.Index(
                fields=["artifact", "perturbationtarget"],
                name="wetlab_arti_artifac_2674c5_idx",
            ),
        ),
    ]
