# Generated by Django 5.1.12 on 2025-09-29 00:46

import lamindb.base.fields
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("wetlab", "0042_biologic_page_biosample_page_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="biologic",
            name="is_locked",
            field=lamindb.base.fields.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="biosample",
            name="is_locked",
            field=lamindb.base.fields.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="combinationperturbation",
            name="is_locked",
            field=lamindb.base.fields.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="compound",
            name="is_locked",
            field=lamindb.base.fields.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="compoundperturbation",
            name="is_locked",
            field=lamindb.base.fields.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="donor",
            name="is_locked",
            field=lamindb.base.fields.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="environmentalperturbation",
            name="is_locked",
            field=lamindb.base.fields.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="experiment",
            name="is_locked",
            field=lamindb.base.fields.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="geneticperturbation",
            name="is_locked",
            field=lamindb.base.fields.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="perturbationtarget",
            name="is_locked",
            field=lamindb.base.fields.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="techsample",
            name="is_locked",
            field=lamindb.base.fields.BooleanField(blank=True, default=False),
        ),
        migrations.AddField(
            model_name="well",
            name="is_locked",
            field=lamindb.base.fields.BooleanField(blank=True, default=False),
        ),
    ]
