# Generated by Django 5.2 on 2025-09-08 09:02

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("wetlab", "0040_compound_canonical_smiles_compound_inchikey_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="artifactbiologic",
            options={},
        ),
        migrations.AlterModelOptions(
            name="artifactbiosample",
            options={},
        ),
        migrations.AlterModelOptions(
            name="artifactcombinationperturbation",
            options={},
        ),
        migrations.AlterModelOptions(
            name="artifactcompound",
            options={},
        ),
        migrations.AlterModelOptions(
            name="artifactcompoundperturbation",
            options={},
        ),
        migrations.AlterModelOptions(
            name="artifactdonor",
            options={},
        ),
        migrations.AlterModelOptions(
            name="artifactenvironmentalperturbation",
            options={},
        ),
        migrations.AlterModelOptions(
            name="artifactexperiment",
            options={},
        ),
        migrations.AlterModelOptions(
            name="artifactgeneticperturbation",
            options={},
        ),
        migrations.AlterModelOptions(
            name="artifactperturbationtarget",
            options={},
        ),
        migrations.AlterModelOptions(
            name="artifacttechsample",
            options={},
        ),
        migrations.AlterModelOptions(
            name="artifactwell",
            options={},
        ),
    ]
