# Generated by Django 5.1.12 on 2025-09-28 23:37

import django.db.models.deletion
import lamindb.base.fields
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("lamindb", "0124_page_artifact_page_collection_page_feature_page_and_more"),
        ("wetlab", "0041_alter_artifactbiologic_options_and_more"),
    ]

    # this migration was later reverted, so we do not need to run it
    operations = []  # type: ignore
