# Generated by Django 5.2 on 2025-11-12 09:38

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("wetlab", "0045_remove_biologic_page_remove_biosample_page_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="artifactgeneticperturbation",
            index=models.Index(
                fields=["artifact", "geneticperturbation"],
                name="wetlab_arti_artifac_8731fa_idx",
            ),
        ),
    ]
