# Generated by Django 5.1.4 on 2025-03-16 19:28

import lamindb.base.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("wetlab", "0034_lamindbv1_part6"),
    ]

    operations = [
        migrations.AlterField(
            model_name="biologic",
            name="targets",
            field=models.ManyToManyField(
                related_name="biologics", to="wetlab.perturbationtarget"
            ),
        ),
        migrations.AlterField(
            model_name="compound",
            name="name",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None
            ),
        ),
        migrations.AlterField(
            model_name="compoundperturbation",
            name="targets",
            field=models.ManyToManyField(
                related_name="compound_perturbations", to="wetlab.perturbationtarget"
            ),
        ),
        migrations.AlterField(
            model_name="environmentalperturbation",
            name="targets",
            field=models.ManyToManyField(
                related_name="environmental_perturbations",
                to="wetlab.perturbationtarget",
            ),
        ),
        migrations.AlterField(
            model_name="geneticperturbation",
            name="targets",
            field=models.ManyToManyField(
                related_name="genetic_perturbations", to="wetlab.perturbationtarget"
            ),
        ),
    ]
