# Generated by Django 5.1.12 on 2025-10-01 14:40

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("wetlab", "0044_alter_biologic_is_locked_alter_biosample_is_locked_and_more"),
    ]

    # this migration reverts a migration that we meanwhile removed
    operations = []  # type: ignore
