# Generated by Django 5.1.11 on 2025-08-02 18:33

import lamindb.base.fields
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("wetlab", "0039_alter_biologic_description_alter_biologic_synonyms_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="compound",
            name="canonical_smiles",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AddField(
            model_name="compound",
            name="inchikey",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AddField(
            model_name="compound",
            name="molformula",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AddField(
            model_name="compound",
            name="molweight",
            field=lamindb.base.fields.FloatField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AddField(
            model_name="compound",
            name="smiles",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
    ]
